/*==============================================================================

FICHIER     : [avancement.h]

DATE        : 2006/01/0005 21:13:17

CREATEUR    : [Linux!jef]

COMMENTAIRE :

================================================================================

==============================================================================*/

#ifndef __AVANCEMENT_H__
#define __AVANCEMENT_H__

#include <gnome.h>
#include "tampon.h"

/*@$#[avancement.c] global proto. AutoProtoSigV1.1. date: 2009/02/04 23:15:03 */
#include "proto.h"
#ifdef __cplusplus
extern "C" {
#endif
/* avancement.c */
void PushAvancement PROTO((void));
void PopAvancement PROTO((void));
void InitAvancement PROTO((int sectors));
void CreateAvancement PROTO((GtkWidget *forme));
void HideMpegVisu PROTO((void));
void DestroyAvancement PROTO((void));
int Avancement PROTO((int lenReaded));
int AvancementAbs PROTO((long pos));
void SetTotalSize PROTO((long long tSize));
void SetTotalSteps PROTO((int steps));
void NewStep PROTO((void));
int AvancementUi PROTO((Tampon *tampon));
int AvancementUi2 PROTO((double pcts));
void DisplayAvancement PROTO((char *format, ...));
void TotalTime PROTO((char *string));
void ResetUserStop PROTO((void));
int IsUserStop PROTO((void));
#ifdef __cplusplus
}
#endif
/*@$% end of AutoProtoSigV1.1 (Dont remove this line) [-I ../include]*/
#endif	/* __AVANCEMENT_H__ */

